@@ -1,9 +1,8 @@
 /*
 ################################################################################
 #
-# r8168 is the Linux device driver released for RealTek RTL8168B/8111B,
-# RTL8168C/8111C, RTL8168CP/8111CP, RTL8168D/8111D, and RTL8168DP/8111DP, and
-# RTK8168E/8111E Gigabit Ethernet controllers with PCI-Express interface.
+# r8168 is the Linux device driver released for Realtek Gigabit Ethernet
+# controllers with PCI-Express interface.
 #
 # Copyright(c) 2013 Realtek Semiconductor Corp. All rights reserved.
 #
