@@ -1,8 +1,8 @@
 /*
 ################################################################################
 #
-# r8101 is the Linux device driver released for RealTek RTL8101E, RTL8102E,
-# and RTL8103E Fast Ethernet controllers with PCI-Express interface.
+# r8168 is the Linux device driver released for Realtek Gigabit Ethernet
+# controllers with PCI-Express interface.
 #
 # Copyright(c) 2013 Realtek Semiconductor Corp. All rights reserved.
 #
